@@ -325,19 +325,19 @@ ConduitConfigWidget::ConduitConfigWidget(TQWidget *parent, const char *n,
 	fStack->setMinimumSize(fStack->sizeHint()+TQSize(10,40));
 
 	TQObject::connect(fConduitList,
-		TQT_SIGNAL(selectionChanged(TQListViewItem *)),
-		this,TQT_SLOT(selected(TQListViewItem *)));
+		TQ_SIGNAL(selectionChanged(TQListViewItem *)),
+		this,TQ_SLOT(selected(TQListViewItem *)));
 	TQObject::connect(fConduitList,
-		TQT_SIGNAL(clicked(TQListViewItem*)),
-		this, TQT_SLOT(conduitsChanged(TQListViewItem*)));
+		TQ_SIGNAL(clicked(TQListViewItem*)),
+		this, TQ_SLOT(conduitsChanged(TQListViewItem*)));
 
 	// Deprecated?
 	TQObject::connect(fConfigureButton,
-		TQT_SIGNAL(clicked()),
-		this,TQT_SLOT(configure()));
+		TQ_SIGNAL(clicked()),
+		this,TQ_SLOT(configure()));
 
-	TQObject::connect(fConfigureWizard,TQT_SIGNAL(clicked()),
-		this,TQT_SLOT(configureWizard()));
+	TQObject::connect(fConfigureWizard,TQ_SIGNAL(clicked()),
+		this,TQ_SLOT(configureWizard()));
 
 	fGeneralPage->setSelected(true);
 	fConduitList->setCurrentItem(fGeneralPage);
@@ -596,7 +596,7 @@ void ConduitConfigWidget::loadAndConfigure(TQListViewItem *p) // ,bool exec)
 		TQStringList a;
 		a.append(CSL1("modal"));
 
-		o = f->create(TQT_TQOBJECT(fStack), 0L, "ConduitConfigBase", a);
+		o = f->create(fStack, 0L, "ConduitConfigBase", a);
 
 		if (!o)
 		{
@@ -651,7 +651,7 @@ void ConduitConfigWidget::loadAndConfigure(TQListViewItem *p) // ,bool exec)
 		fCurrentConfig=d;
 		// make sure the changed signal is propagated to the KCM*Dialog
 		// and the apply button is enabled correspondingly.
-		connect(d, TQT_SIGNAL(changed(bool)), this, TQT_SIGNAL(changed(bool)));
+		connect(d, TQ_SIGNAL(changed(bool)), this, TQ_SIGNAL(changed(bool)));
 	}
 }
 
@@ -694,7 +694,7 @@ void ConduitConfigWidget::selected(TQListViewItem *p)
 		if (!release())
 		{
 			fConduitList->blockSignals(true);
-			TQTimer::singleShot(1,this,TQT_SLOT(unselect()));
+			TQTimer::singleShot(1,this,TQ_SLOT(unselect()));
 			return;
 		}
 	}
