@@ -44,7 +44,7 @@ class FileInstaller;
 
 class FileInstallWidget : public PilotComponent
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
