@@ -52,7 +52,7 @@ protected:
 
 class DeviceConfigPage : public ConfigPage
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	DeviceConfigPage( TQWidget *, const char * );
@@ -90,7 +90,7 @@ private:
 
 class BackupConfigPage : public ConfigPage
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	BackupConfigPage( TQWidget *, const char * );
