@@ -40,7 +40,7 @@ class TQTextView;
 
 class TodoListView : public TDEListView
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	TodoListView(TQWidget * parent = 0, const char * name = 0 ):TDEListView(parent, name){};
@@ -66,7 +66,7 @@ public:
 
 class TodoWidget : public PilotComponent
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
@@ -144,7 +144,7 @@ private:
 	* currently selected category.
 	*
 	* The entire todo database is read into memory in the
-	* TQList fTodoList. We need the appinfo block from the
+	* TQPtrList fTodoList. We need the appinfo block from the
 	* database to determine which categories there are; this
 	* is held in fTodoAppInfo.
 	*
