@@ -170,7 +170,7 @@ class PilotDatabase;
 */
 class KDE_EXPORT KPilotLink : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 friend class SyncAction;
 public:
