@@ -607,17 +607,17 @@ ConduitProxy::ConduitProxy(KPilotLink *p,
 	addSyncLogEntry(i18n("[Conduit %1]").arg(fDesktopName));
 
 	// Handle the syncDone signal properly & unload the conduit.
-	TQObject::connect(fConduit,TQT_SIGNAL(syncDone(SyncAction *)),
-		this,TQT_SLOT(execDone(SyncAction *)));
+	TQObject::connect(fConduit,TQ_SIGNAL(syncDone(SyncAction *)),
+		this,TQ_SLOT(execDone(SyncAction *)));
 	// Proxy all the log and error messages.
-	TQObject::connect(fConduit,TQT_SIGNAL(logMessage(const TQString &)),
-		this,TQT_SIGNAL(logMessage(const TQString &)));
-	TQObject::connect(fConduit,TQT_SIGNAL(logError(const TQString &)),
-		this,TQT_SIGNAL(logError(const TQString &)));
-	TQObject::connect(fConduit,TQT_SIGNAL(logProgress(const TQString &,int)),
-		this,TQT_SIGNAL(logProgress(const TQString &,int)));
+	TQObject::connect(fConduit,TQ_SIGNAL(logMessage(const TQString &)),
+		this,TQ_SIGNAL(logMessage(const TQString &)));
+	TQObject::connect(fConduit,TQ_SIGNAL(logError(const TQString &)),
+		this,TQ_SIGNAL(logError(const TQString &)));
+	TQObject::connect(fConduit,TQ_SIGNAL(logProgress(const TQString &,int)),
+		this,TQ_SIGNAL(logProgress(const TQString &,int)));
 
-	TQTimer::singleShot(0,fConduit,TQT_SLOT(execConduit()));
+	TQTimer::singleShot(0,fConduit,TQ_SLOT(execConduit()));
 	return true;
 }
 
