@@ -55,7 +55,7 @@ protected:
 	virtual TQObject *createObject(
 		TQObject* parent = 0,
 		const char* name = 0,
-		const char* classname = TQOBJECT_OBJECT_NAME_STRING,
+		const char* classname = "TQObject",
 		const TQStringList &args = TQStringList() )
 	{
 		if (qstrcmp(classname,"ConduitConfigBase")==0)
